.report-header {
    height: 10ex;
    background-color: #299aca;
    padding: 1ex;
    color: #ffffff;
    margin-bottom: 2ex;
}

.report-header a {
    color: #ffffff;
    text-decoration: none;
    font-size: 80%;
}

.report-link {
}

.report-title {
    padding-top: 1ex;
    padding-bottom: 1ex;
    float: left;
    font-size: 200%;
}

.generated-on {
    padding-top: 5ex;
    float: right;
    text-align: right;
}

#body-content {
    margin: 1ex;
}

body {
    margin: 0px;
    font-family: sans-serif;
}

table {
    border-collapse: collapse;
    /* border-spacing: 0px; */
}

table.sortable th:not(.sorttable_sorted):not(.sorttable_sorted_reverse):not(.sorttable_nosort):after {
    content: " \25B4\25BE"
}

th {
    border: solid 1px #c0c0c0;
    padding-right: 0.5ex;
    font-size: 80%;
}

td {
    border: solid 1px #c0c0c0;
    padding-left: 0.5ex;
    padding-right: 0.5ex;
}

.call-sites {
    font-family: monospace;
    padding-left: 1.5em;
    margin-bottom: 1em;
    color: #707070;
}

.callees {
    font-family: monospace;
    padding-left: 1.5em;
    margin-bottom: 1em;
    color: #707070;
}

.code {
    font-family: monospace;
    white-space: pre;
}

.line-number {
    text-align: right;
}

.coverage-number {
    text-align: center;
}

.coverage-red {
    background-color: #ff9999;
}

.coverage-orange {
    background-color: #ffcc99;
}

.coverage-yellow {
    background-color: #ffff99;
}

.coverage-green {
    background-color: #99ff99;
}

